middleware

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Handler

type Handler func(context.Context, events.Event) error

Handler is executed by the middleware chain. It operates on events and can return an error to signal failure to upstream callers.

func Chain

func Chain(h Handler, mws ...Middleware) Handler

Chain applies middlewares in the order they are provided, producing a final handler. The last middleware wraps the provided handler.

type Middleware

type Middleware func(Handler) Handler

Middleware wraps a Handler, typically adding cross-cutting concerns such as logging, tracing or metrics.

Jump to